# Generated by roxygen2: do not edit by hand

S3method(augment,coresynth)
S3method(glance,coresynth)
S3method(glance,coresynth_inference)
S3method(plot,coresynth)
S3method(plot,scm_design)
S3method(print,conformal_inference)
S3method(print,coresynth)
S3method(print,coresynth_inference)
S3method(print,pred_spec)
S3method(print,scm_design)
S3method(print,sdid_inference)
S3method(summary,coresynth)
S3method(summary,scm_design)
S3method(tidy,coresynth)
S3method(tidy,coresynth_inference)
export(augment_scm)
export(conformal_inference)
export(export_json)
export(gsc_boot)
export(gsc_ife_cpp)
export(gsc_inference)
export(kalman_smoother_cpp)
export(mspe_ratio_pval)
export(pred)
export(scm_design)
export(scm_fit)
export(scm_inner_weights_cpp)
export(scm_placebo_cpp)
export(scm_weights_cpp)
export(sdid_estimate_cpp)
export(sdid_inference)
export(sdid_placebo_cpp)
export(sdid_time_weights_cpp)
export(sdid_unit_weights_cpp)
export(si_inference)
export(si_pcr_cpp)
export(soft_impute_cpp)
export(tensor_unfold_cpp)
import(ggplot2)
importFrom(Rcpp,sourceCpp)
importFrom(broom,augment)
importFrom(broom,glance)
importFrom(broom,tidy)
importFrom(stats,complete.cases)
importFrom(stats,median)
importFrom(stats,optim)
importFrom(stats,pnorm)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,reorder)
importFrom(stats,rnorm)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,var)
importFrom(utils,combn)
importFrom(utils,packageVersion)
useDynLib(coresynth, .registration = TRUE)
