% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RcppExports.R
\name{scm_inner_weights_cpp}
\alias{scm_inner_weights_cpp}
\title{SCM Inner Weights (QP Given V)}
\usage{
scm_inner_weights_cpp(X0, X1, V_diag)
}
\arguments{
\item{X0}{Covariate matrix for control units (k x N_co)}

\item{X1}{Covariate vector for the treated unit (k x 1)}

\item{V_diag}{Diagonal of the metric matrix V (k x 1, non-negative, need not sum to 1)}
}
\value{
Donor weight vector W (N_co x 1) on the unit simplex
}
\description{
Solves the inner-loop QP for SCM: given a fixed diagonal metric matrix V,
finds donor weights W on the simplex minimising the V-weighted covariate loss.
}
