% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/broom.R
\name{glance.coresynth_inference}
\alias{glance.coresynth_inference}
\title{Glance at an inference result}
\usage{
\method{glance}{coresynth_inference}(x, ...)
}
\arguments{
\item{x}{An inference object.}

\item{...}{Unused.}
}
\value{
A one-row \code{data.frame} with columns \code{method}, \code{n_controls},
\code{staggered}, \code{estimate}, \code{std.error}, \code{p.value}, \code{conf.low},
\code{conf.high}, \code{alternative}, \code{n_boot_valid}.
}
\description{
One-row summary of a \code{coresynth_inference} (or \code{sdid_inference}) object.
}
